
# Type: variant to population association_has total




URI: [biolink:variant_to_population_association_has_total](https://w3id.org/biolink/vocab/variant_to_population_association_has_total)


## Domain and Range

[VariantToPopulationAssociation](VariantToPopulationAssociation.md) ->  <sub>OPT</sub> [Integer](types/Integer.md)

## Parents

 *  is_a: [has total](has_total.md)

## Children


## Used by

 * [VariantToPopulationAssociation](VariantToPopulationAssociation.md)
